Directly the sysconf function.
Unlike the other modules in this crate, which provide convenience wrappers to query various
configuration information, the raw module provides the ability to call the sysconf function
directly.
Enums
- Sysconf
Error - The error returned by
sysconf. - Sysconf
Variable - The variables that can be queried using
sysconf.
Functions
- sysconf
- Query the system’s configuration.